@@ -28,7 +28,6 @@ sub run {
 	my ($chromosomes, $parents, $crossover) = ($ga->chromosomes, $ga->_parents, $ga->crossover);
 	my ($fitness, $_fitness) = ($ga->fitness, $ga->_fitness);
 	my $high  = scalar @{$chromosomes->[0]};
-	my $len = $#{$chromosomes->[0]};
 	my @children;
 	#-------------------------------------------------------------------
 	while(my $elders = shift @$parents){
@@ -41,28 +40,29 @@ sub run {
 		}
 		
 		#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+		my $len = scalar @elders;
 		my @seq;
 		if($self->{type} eq q/uniform/){
 			@seq = random_uniform_integer($high, 0, $#elders);
 		}elsif($self->{type} eq q/normal/){
 			my $av = defined $self->{params}->[0] ? $self->{params}->[0] : $len/2;
 			my $sd = defined $self->{params}->[1] ? $self->{params}->[1] : $len;
-			@seq = map { int $_ % $high } random_normal($high, $av, $sd)  
+			@seq = map { $_ % $len } random_normal($high, $av, $sd);
 		}elsif($self->{type} eq q/beta/){
-			my $aa = defined $self->{params}->[0] ? $self->{params}->[0] : $high;
-			my $bb = defined $self->{params}->[1] ? $self->{params}->[1] : $high;
-			@seq = map { int($_ * $high) } random_beta($high, $aa, $bb)
+			my $aa = defined $self->{params}->[0] ? $self->{params}->[0] : $len;
+			my $bb = defined $self->{params}->[1] ? $self->{params}->[1] : $len;
+			@seq = map { int($_ * $len) } random_beta($high, $aa, $bb);
 		}elsif($self->{type} eq q/binomial/){
-			@seq = random_binomial($high, $len, rand);
+			@seq = random_binomial($high, $#elders, rand);
 		}elsif($self->{type} eq q/chi_square/){
-			my $df = defined $self->{params}->[0] ? $self->{params}->[0] : $high;
-			@seq = map { int $_ % $high } random_chi_square($parents, $df);
+			my $df = defined $self->{params}->[0] ? $self->{params}->[0] : $len;
+			@seq = map { $_ % $len } random_chi_square($high, $df);
 		}elsif($self->{type} eq q/exponential/){
 			my $av = defined $self->{params}->[0] ? $self->{params}->[0] : $len/2;
-			@seq = map { int $_ % $high } random_exponential($parents, $av);
+			@seq = map { $_ % $len } random_exponential($high, $av);
 		}elsif($self->{type} eq q/poisson/){
 			my $mu = defined $self->{params}->[0] ? $self->{params}->[0] : $len/2;
-			@seq = map { int $_ % $high } random_poisson($parents, $mu) ;
+			@seq = map { $_ % $len } random_poisson($high, $mu) ;
 		}else{
 			die qq/Unknown distribution "$self->{type}" in "crossover"!\n/;
 		}
